Querschnittswerte — stanpy 0.2.2 documentation
Description: Examples of document structure features in pydata-sphinx-theme.

# Querschnittswerte

Note

todos: Abbildungen, Definition der Vektoren h und b, Funktion für I, H, HEB, HEA, ...

In diesem Abschnitt werden die Querschnittswerte für verschieden zusammengesetzte Rechtecksquerschnitte berechnet.

## EX01 Rechtecksquerschnitt

    import numpy as np
    import stanpy as stp
    import matplotlib.pyplot as plt

    b = 0.2  # m
    h = 0.4 # m

    cs_props = stp.cs(b=b,h=h)

    print(cs_props)

    offset = 0.2
    fig, ax = plt.subplots()
    stp.plot_cs(ax, b, h)
    ax.set_xlim(-offset, np.max(b) + offset)
    ax.set_ylim(-offset, np.max(h) + offset)
    ax.grid(linestyle=":")
    ax.axis('equal')
    plt.show()

    {'A': 0.08000000000000002,
     'I_y': 0.001066666666666667,
     'I_z': 0.00026666666666666673,
     'y_s': 0.1,
     'z_s': 0.2}

## EX02 Zusammengesetzter Rechtecksquerschnitt

    import numpy as np
    import stanpy as stp
    import matplotlib.pyplot as plt

    s, t = 0.012, 0.02  # m
    b, h = 0.3, 0.4 # m
    b_v = np.array([b, s, b])
    h_v = np.array([t, h - 2 * t, t])
    zsi_v = np.array([t / 2, t + (h - 2 * t) / 2, t + (h - 2 * t) + t / 2])  # von OK
    ysi_v = np.array([b/2, b/2, b/2])  # von Links

    cs_props = stp.cs(b=b_v, h=h_v, y_si=ysi_v, z_si=zsi_v)
    print(cs_props)
    offset = 0.2
    fig, ax = plt.subplots()
    stp.plot_cs(ax, b_v, h_v, ysi_v, zsi_v)
    ax.set_xlim(-offset, np.max(b) + offset)
    ax.set_ylim(-offset, np.max(h) + offset)
    ax.grid(linestyle=":")
    ax.axis('equal')
    plt.show()

    {'A': 0.01632,
     'I_y': 0.0004802560000000001,
     'I_z': 9.005184000000001e-05,
     'y_s': 0.15,
     'z_s': 0.20000000000000004}

## EX03 I-Querschnitt

    import numpy as np
    import matplotlib.pyplot as plt
    import stanpy as stp
    import matplotlib.pyplot as plt

    s, t = 0.012, 0.02  # m
    b, h = 0.3, 0.4 # m
    b_v = np.array([b, s, b])
    h_v = np.array([t, h - 2 * t, t])
    ysi_v = stp.AI_y.dot(b_v) # von OK
    zsi_v = stp.AI_z.dot(h_v) # von Links

    cs_props = stp.cs(b=b_v, h=h_v, y_si=ysi_v, z_si=zsi_v)

    print(cs_props)

    offset = 0.2
    fig, ax = plt.subplots()
    stp.plot_cs(ax, b_v, h_v, ysi_v, zsi_v)
    ax.set_xlim(-offset, np.max(b) + offset)
    ax.set_ylim(-offset, np.max(h) + offset)
    ax.grid(linestyle=":")
    ax.axis('equal')
    plt.show()

    {'A': 0.01632,
     'I_y': 0.0004802560000000001,
     'I_z': 9.005184000000001e-05,
     'y_s': 0.15,
     'z_s': 0.20000000000000004}

## EX04 H-Querschnitt

    import numpy as np
    import stanpy as stp
    import matplotlib.pyplot as plt

    s, t = 0.02, 0.02  # m
    b, h = 0.3, 0.4 # m

    b_v = np.array([t, h - 2 * t, t])
    h_v = np.array([b, s, b])
    ysi_v = stp.AH_y.dot(b_v) # von OK
    zsi_v = stp.AH_z.dot(h_v) # von Links

    cs_props = stp.cs(b=b_v, h=h_v, y_si=ysi_v, z_si=zsi_v)

    print(cs_props)

    offset = 0.2
    fig, ax = plt.subplots()
    stp.plot_cs(ax, b_v, h_v, ysi_v, zsi_v)
    ax.set_xlim(-offset, np.max(b) + offset)
    ax.set_ylim(-offset, np.max(h) + offset)
    ax.grid(linestyle=":")
    ax.axis('equal')
    plt.show()

    {'A': 0.019200000000000002,
     'I_y': 9.024000000000011e-05,
     'I_z': 0.0005113600000000001,
     'y_s': 0.20000000000000004,
     'z_s': 0.14999999999999997}

## EX05 Kasten-Querschnitt

    import numpy as np
    import stanpy as stp
    import matplotlib.pyplot as plt

    s, t = 0.012, 0.02  # m
    b, h = 0.3, 0.4 # m

    b_v = np.array([b, s, s, b])
    h_v = np.array([t, h - 2 * t, h - 2 * t, t])
    ysi_v = stp.AK_y.dot(b_v) # von OK
    zsi_v = stp.AK_z.dot(h_v) # von Links

    cs_props = stp.cs(b=b_v, h=h_v, z_si=zsi_v, y_si=ysi_v)

    print(cs_props)

    offset = 0.2
    fig, ax = plt.subplots()
    stp.plot_cs(ax, b_v, h_v, ysi_v, zsi_v)
    ax.set_xlim(-offset, np.max(b) + offset)
    ax.set_ylim(-offset, np.max(h) + offset)
    ax.grid(linestyle=":")
    ax.axis('equal')
    plt.show()

    {'A': 0.020640000000000002,
     'I_y': 0.000526912,
     'I_z': 0.0002692627199999998,
     'y_s': 0.15000000000000002,
     'z_s': 0.2}

## EX06 - Verstärkter I Querschnitt

    import numpy as np
    import stanpy as stp
    import matplotlib.pyplot as plt

    s, t = 0.012, 0.02  # m
    b, h = 0.3, 0.4 # m
    h_i = 0.05  # m

    b_v = np.array([b, s, b, s, s, s, s])
    h_v = np.array([t, h - 2 * t, t, h_i, h_i, h_i, h_i])
    ysi_v = stp.AI_yp.dot(b_v) # von OK
    zsi_v = stp.AI_zp.dot(h_v) # von Links

    cs_props = stp.cs(b=b_v, h=h_v, z_si=zsi_v, y_si=ysi_v)

    print(cs_props)

    offset = 0.2
    fig, ax = plt.subplots()
    stp.plot_cs(ax, b_v, h_v, ysi_v, zsi_v)
    ax.set_xlim(-offset, np.max(b) + offset)
    ax.set_ylim(-offset, np.max(h) + offset)
    ax.grid(linestyle=":")
    ax.axis('equal')
    plt.show()

    {'A': 0.01872,
     'I_y': 0.0005384160000000002,
     'I_z': 0.00013984703999999986,
     'y_s': 0.15000000000000002,
     'z_s': 0.20000000000000004}

previous

User Guide

next

Querschnittswerte für Stäbe mit veränderlichen Querschnittsabmessungen